# foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

A document without any content.

Let var be a string.

Reverse var and return the result.

Here’s a, a single char.

Here’s ab, two chars.

Here’s abc, three chars.

Here’s some grammar: foo | bar | baz | qux

Here’s some more: foo || bar || baz || qux

Here’s foo bar, multi word.

Here’s foo-bar, dashed.

Here’s a "real" foo bar.

Here’s one with a linebreak: foo bar with a linebreak.

This one has no linebreak: foo bar with a linebreak. This shouldn’t generate a warning.